@@ -11,7 +11,7 @@ from time import sleep as time_sleep
 from typing import List, Optional, Tuple
 
 from tqdm import tqdm
-from ycontract import in_contract, out_contract
+from ycontract import contract
 
 DEFAULT_RING_FILENAME = "ring.mp3"
 
@@ -59,7 +59,7 @@ def is_time_delta_str(s: str) -> bool:
     return s == ""
 
 
-@out_contract(lambda sec: sec >= 0)
+@contract(returns=lambda sec: sec >= 0)
 def get_time_delta_from_str(s: str) -> int:
     if s.isdigit():
         return int(s)
@@ -94,8 +94,7 @@ def is_specific_time_str(s: str) -> bool:
     return 0 <= sec < 60 and 0 <= min_ < 60
 
 
-@in_contract(is_specific_time_str)
-@out_contract(lambda res: res[0] >= 0 and res[1] >= 0 and res[2] >= 0)
+@contract(is_specific_time_str, returns=lambda res: res[0] >= 0 and res[1] >= 0 and res[2] >= 0)
 def get_specific_time_from_str(s: str) -> Tuple[int, int, int]:
     number_strs = s.split(":")
     number_strs = [s.replace(" ", "") for s in number_strs]
@@ -107,11 +106,11 @@ def get_specific_time_from_str(s: str) -> Tuple[int, int, int]:
     return (hour, min_, sec)
 
 
-@in_contract(
+@contract(
     lambda time_: time_[0] >= 0 and time_[1] >= 0 and time_[2] >= 0,
     lambda now_: now_[0] >= 0 and now_[1] >= 0 and now_[2] >= 0,
+    returns=lambda sec: sec >= 0,
 )
-@out_contract(lambda sec: sec >= 0)
 def convert_specific_time_to_time_delta(
         time_: Tuple[int, int, int], now_: Tuple[int, int, int]) -> int:
     sec = (time_[0] - now_[0]) * 60 * 60 + (time_[1] - now_[1]) * 60 + (time_[2] - now_[2])
@@ -170,7 +169,7 @@ def notify(title: str, message: str, cmd_io=None) -> None:
         print(cmd, file=cmd_io)
 
 
-@in_contract(lambda spend_sec: spend_sec >= 0)
+@contract(lambda spend_sec: spend_sec >= 0)
 def notify_all(
     title: str,
     message: str,
